SiFT - Biological signal filtering in single-cell data
======================================================

.. image:: https://raw.githubusercontent.com/nitzanlab/sift-sc/main/docs/_static/img/sift_gc.png
    :width: 200px
    :align: center
    :alt: SiFT logo

Signal FilTering is a tool for uncovering hidden biological processes in single-cell data.
It can be applied to a wide range of tasks, from the removal of unwanted variation as a pre-processing step,
through revealing hidden biological structure by utilizing prior knowledge with respect to existing signal,
to uncovering trajectories of interest using reference data to remove unwanted variation.

.. image:: https://raw.githubusercontent.com/nitzanlab/sift-sc/main/docs/_static/img/sift_abs.png
    :width: 600px
    :align: center
    :alt: SiFT pipeline

Visit our `documentation`_ for installation, tutorials, examples and more.

Manuscript
----------
Please see our manuscript `Zoe Piran and Mor Nitzan (2022)`_.

Installation
------------
Install SiFT via PyPI by running::

    pip install sift-sc

.. _documentation: https://sift-sc.readthedocs.io/
.. _Zoe Piran and Mor Nitzan (2022): https://github.com/nitzanlab/sift-sc
